#
# spec file for package kubo
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define repo github.com/ipfs/kubo
Name:           kubo
Version:        0.35.0
Release:        bp156.2.6.1
Summary:        IPFS implementation in Go
License:        MIT
Group:          Productivity/Networking/Other
URL:            https://%{repo}
Source0:        kubo-%{version}.tar
Source1:        vendor.tar.zst

BuildRequires:  git
# >= 1.14.4 is ambiguous
BuildRequires:  go1.24
BuildRequires:  systemd-rpm-macros
BuildRequires:  zstd
Requires:       fuse
Requires:       nss-myhostname
%systemd_requires

Provides:       go-ipfs = %{version}
Provides:       ipfs
Obsoletes:      go-ipfs <= 0.21.0

%description
IPFS is a global, versioned, peer-to-peer filesystem.
It combines good ideas from Git, BitTorrent, Kademlia, SFS, and the Web.
It is like a single bittorrent swarm, exchanging git objects.
IPFS provides an interface as simple as the HTTP web, but with permanence built in.
You can also mount the world at /ipfs.

%prep
%autosetup -p1 -a1

%build
go build -mod=vendor -buildmode=pie -v -o ./cmd/ipfs/ipfs ./cmd/ipfs
#make build

%install
#make install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_userunitdir}
mkdir -p %{buildroot}%{_unitdir}

cp cmd/ipfs/ipfs %{buildroot}%{_bindir}
cat << EOF >>  %{buildroot}%{_userunitdir}/ipfs.service
[Unit]
Description=InterPlanetary File System (IPFS) daemon
After=network-online.target
Wants=network-online.target

[Service]
ExecStart=/usr/bin/ipfs daemon
Restart=on-failure

[Install]
WantedBy=default.target
EOF
cat << EOF >> %{buildroot}%{_unitdir}/ipfs@.service
[Unit]
Description=InterPlanetary File System (IPFS) daemon
After=network-online.target
Wants=network-online.target

[Service]
User=%i
ExecStart=/usr/bin/ipfs daemon
Restart=on-failure

[Install]
WantedBy=default.target
EOF

rm -rf docs/examples/example-folder/test-dir/

%pre
#service_add_pre ipfs@.service

%post
#service_add_post ipfs@.service

%preun
#service_del_preun ipfs@.service

%postun
#service_del_postun ipfs@.service

%files
%{_bindir}/ipfs
%{_userunitdir}/ipfs.service
%{_unitdir}/ipfs@.service
%license LICENSE*
%doc docs/*

%changelog
* Thu May 22 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- 0.35.0
  * Opt-in HTTP Retrieval client
  * Dedicated Reprovider.Strategy for MFS
  * Experimental support for MFS as a FUSE mount point
  * Grid view in WebUI
  * Enhanced DAG-Shaping Controls
  * Datastore Metrics Now Opt-In
  * Improved performance of data onboarding
  * Optimized, dedicated queue for providing fresh CIDs
  * New Provider configuration options
  * Deprecated ipfs stats provider
  * New Bitswap configuration options
  * Bitswap.Libp2pEnabled
  * Bitswap.ServerEnabled
  * Internal.Bitswap.ProviderSearchMaxResults
  * New Routing configuration options
  * Routing.IgnoreProviders
  * Routing.DelegatedRouters
  * New Pebble database format config
  * New environment variables
  * Improved Log Output Setting
  * New Repo Lock Optional Wait
  * Updated golang.org/x/net to 0.39.0 (boo#1241776, CVE-2025-22872)
* Tue Apr  1 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Build with -v flag
- Update to 0.34.1 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.34.1
  * Dependency updates
- Update to 0.34.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.34.0
  * AutoTLS now enabled by default for nodes with 1 hour uptime
  * New WebUI features: CAR file import and QR code sharing
  * RPC and CLI command changes
    ~ ipfs config is now validating json fields
    ~ Deprecated the bitswap reprovide command
    ~ The stats reprovide command now shows additional stats
    ~ ipfs files cp now performs basic codec check
  * Bitswap improvements from Boxo
  * IPNS publishing TTL change
    ~ we’ve lowered the default IPNS Record TTL during publishing
    to 5 minutes
  * IPFS_LOG_LEVEL deprecated
  * Pebble datastore format update
  * Badger datastore update
  * Datastore Implementation Updates
  * Datastore Implementation Updates
  * Fix hanging pinset operations during reprovides
  * Important dependency updates
* Mon Feb 17 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Update to 0.33.1 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.33.1
  * Bitswap improvements from Boxo
  * Improved IPNS interop
- Update to 0.33.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.33.0
  * Shared TCP listeners: Kubo now supports sharing the same TCP
    port (4001 by default) by both raw TCP and WebSockets libp2p
    transports.
  * AutoTLS takes care of Secure WebSockets setup: It is no longer
    necessary to manually add /tcp/../ws listeners to
    Addresses.Swarm when AutoTLS.Enabled is set to true. Kubo will
    detect if /ws listener is missing and add one on the same port
    as pre-existing TCP (e.g. /tcp/4001), removing the need for any
    extra configuration.
  * Bitswap improvements from Boxo
  * Using default libp2p_rcmgr metrics: Bespoke rcmgr metrics were
    removed, Kubo now exposes only the default libp2p_rcmgr metrics
    from go-libp2p.
  * Flatfs does not sync on each write: New repositories
    initialized with flatfs in Datastore.Spec will have sync set to
    false.
  * ipfs add --to-files no longer works with --wrap
  * ipfs --api supports HTTPS RPC endpoints
  * New options for faster writes: WriteThrough, BlockKeyCacheSize,
    BatchMaxNodes, BatchMaxSize
  * MFS stability with large number of writes
  * New DoH resolvers for non-ICANN DNSLinks: .eth and .crypto
  * Reliability improvements to the WebRTC Direct listener
  * Fix: Escape Redirect URL for Directory
* Thu Jan  9 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.32.1 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.32.1
  * AutoTLS: Automatic Certificates for libp2p WebSockets via libp2p.direct
  * Dependency updates
    + ipfs-webui to v4.4.0
    + boxo to v0.24.3
    + go-libp2p to v0.37.0
    + go-libp2p-kad-dht to v0.28.1
    + go-libp2p-pubsub to v0.12.0
    + p2p-forge/client to v0.0.2
* Fri Oct 25 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to 0.31.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.31.0
  * Experimental Pebble Datastore
  * New metrics
  * lowpower profile no longer breaks DHT announcements
  * go 1.23, boxo 0.24 and go-libp2p 0.36.5
- Update to 0.30.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.30.0
  * Improved P2P connectivity
  * Refactored Bitswap and dag-pb chunker
  * WebRTC-Direct Transport enabled by default
  * UnixFS 1.5: Mode and Modification Time Support
  * AutoNAT V2 Service Introduced Alongside V1
  * Automated ipfs version check
  * Version Suffix Configuration
  * /unix/ socket support in Addresses.API
  * Cleaned Up ipfs daemon Startup Log
  * Commands Preserve Specified Hostname
* Tue Jun 11 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.29.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.29.0
  * Add search functionality for pin names
  * Customizing ipfs add defaults
- drop upstream 10243.patch
- drop upstream kubo-0.27.0-CVE-2024-22189.patch
* Mon Apr  8 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add kubo-0.27.0-CVE-2024-22189.patch to avoid
  quic-go memory exhaustion attack (boo#1222479, CVE-2024-22189)
* Thu Apr  4 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.27.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.27.0
  * Gateway: support for /api/v0 is deprecated
  * IPNS resolver cache's TTL can now be configured via Ipns.MaxCacheTTL
  * RPC client: deprecated DHT API, added Routing API
  * Deprecated DHT commands removed from /api/v0/dht
  * Repository migrations are now trustless
- Let .service files wait for network-online.target (boo#1222194)
* Sat Jan 27 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to 0.26.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.26.0
  * Removed several deprecated commands
  * Support optional pin names
  * jaeger trace exporter has been removed
  * fix quic-go memory exhaustion attack (boo#1235162, CVE-2023-49295)
- Update to 0.25.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.25.0
  * WebUI: Updated Peers View
  * Kubo RPC API now supports optional HTTP Authorization.
  * MPLEX Removal
  * Graphsync Experiment Removal
  * Commands ipfs key sign and ipfs key verify
* Wed Dec  6 2023 Bernhard Wiedemann <bwiedemann@suse.de>
- Add 10243.patch to fix FUSE mounts
* Sat Nov 11 2023 Bernhard M. Wiedemann <bwiedemann@suse.de>
- Update to 0.24.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.24.0
  * Support for content blocking
  * Gateway: the root of the CARs are no longer meaningful
  * IPNS: improved publishing defaults
  * IPNS: record TTL is used for caching
  * Experimental Transport: WebRTC Direct
* Fri Oct  6 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.23.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.23.0
  * Mplex deprecation
  * Gateway: meaningful CAR responses on Not Found errors
  * Gateway: added Gateway.DisableHTMLErrors configuration option
  * Binary characters in file names: no longer works with old clients and new Kubo servers
  * Self-hosting /routing/v1 endpoint for delegated routing needs
  * Trustless Gateway Over Libp2p Experiment
  * Removal of /quic (Draft 29) support
  * Better Caching of multiaddresses for providers in DHT servers
  * Fixed FUSE multiblock structures
* Wed Aug  9 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.22.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.22.0
  * Gateway: support for order= and dups= parameters (IPIP-412)
  * ipfs name publish now supports V2 only IPNS records
  * IPNS name resolution has been fixed
  * go-libp2p v0.29.0 update with smart dialing
* Fri Jul 21 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Rename from go-ipfs to kubo to follow upsteam git repo rename
* Wed Jul  5 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.21.0 - for details see
  * https://github.com/ipfs/kubo/releases/tag/v0.21.0
  * Saving previously seen nodes for later bootstrapping
  * Gateway: DeserializedResponses config flag
  * Gateway: DAG-CBOR/-JSON previews and improved error pages
  * Gateway: subdomain redirects are now text/html
  * Gateway: support for partial CAR export parameters
  * ipfs dag stat deduping statistics
  * Accelerated DHT Client is no longer experimental
  * client/rpc migration of go-ipfs-http-client
* Sat Feb  4 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.18.1 - for details see:
  * https://github.com/ipfs/kubo/releases/tag/v0.18.1
  * https://github.com/ipfs/kubo/releases/tag/v0.18.0
  * Support InterPlanetary Network Indexers
  * Support DAG-JSON and DAG-CBOR in gateways
  * Enable WebTransport by default
  * Improve libp2p resource management integration
* Fri Dec  9 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.17.0 - for details see:
  * https://github.com/ipfs/kubo/releases/tag/v0.17.0
  * https://github.com/ipfs/kubo/releases/tag/v0.16.0
  * https://github.com/ipfs/kubo/releases/tag/v0.15.0
  * https://github.com/ipfs/kubo/releases/tag/v0.14.0
  * libp2p resource management enabled by default
  * Implicit connection manager limits
  * TAR Response Format on Gateways
  * Dialling /wss peer behind a reverse proxy
  * More configurable delegated routing system
  * WebTransport new experimental Transport
  * Hardened IPNS record verification
  * Web Gateways now support _redirects files
  * Add files to MFS with ipfs add --to-files
  * Blake 3 support
  * Fx Options plugin
  * $IPFS_PATH/gateway file
  * Removed mdns_legacy implementation
  * Delegated Routing
  * ipfs repo migrate
  * Emoji support in Multibase
* Fri Jun 10 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.13.0
  * Can now limit how much resource usage libp2p consumes
  * Improve connecting with nodes behind NATs and Firewalls
  * Improve HTTP gateway to allow making faster CDNs
  * Add Gateway.FastDirIndexThreshold configuration, for fast listings
    of big directories, without the linear slowdown caused by reading
    size metadata from child nodes.
  * Improve Etag and If-None-Match
  * Add X-Ipfs-Roots for smarter HTTP caches
  * Added metrics per response type
  * OpenTelemetry tracing
  * Expand diag profile command
  * Support for PEM/PKCS8 for key import/export
  * Use standard IPLD codec names across the CLI/HTTP API
  * Prioritize Yamux over Mplex stream multiplexer
  * https://github.com/ipfs/go-ipfs/releases/tag/v0.13.0 for details
* Fri Feb 18 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.12.0
  * change how data blocks are stored -> needs migration
* Fri Dec 10 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.11.0
  * UnixFS sharding is now automatic and enabled by default
  * can no longer act as a Circuit Relay v1
  * HTTP RPC wire format for experimental commands at /api/v0/pubsub changed
  * Circuit Relay v2
  * New configuration flags:
    + Addresses.AppendAnnounce
    + Pubsub.Enabled
  * changed ipfs dag get
  * changed ipfs dag put
  * UnixFS refactor
  * Add ipfs multibase command
  * Bitswap now supports greater configurability
  * Programmatic shell completions command
  * Profile collection command
  * Add Peering command
* Thu Jun 24 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.9.0
  * Exporting of DAGs via Gateways
  * Custom DNS Resolvers
  * Support for non-ICANN DNSLink names
  * Updated to the latest WebUI
  * IPNS keys can now be exported via the CLI without stopping the daemon
  * Experimental DHT Client and Provider System
  * Deprecations
    + The ipfs object commands are now deprecated
    + X-Ipfs-Gateway-Prefix is now deprecated
    + Proquints support removed
    + SECIO support removed
* Thu Dec 10 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.8.0
  * Add Remote pinning services: ipfs pin remote
  * Faster local pinning and unpinning
  * update quic-go to support QUIC draft-32
* Wed Sep 30 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.7.0
  * Drop upstream 7331.patch
  * Default to Ed25519 keys
  * Secio is now disabled by default
  * IPNS paths now encode the key name as a base36 CIDv1 by default
  * Multiaddresses now accept PeerIDs encoded as CIDv1
  * dag stat command shows size and number of blocks
* Wed May 20 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add 7331.patch to fix ipns resolution
* Fri May  8 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.5.0
  * Improved DHT
  * Improved Content Transfer
  * Refactored Bitswap
  * Stable Badger Datastore
  * Improved Backoff Logic
  * AutoNAT - determining if the node is reachable from the public internet
  * PeerIDs under /p2p/QmSomePeerID instead of /ipfs/QmSomePeerID
  * enforce RSA keys with 2048+ bits
  * TLS By Default
  * Subdomain Gateway now uses http://CID.ipfs.localhost:8080/
  * PubSub is now using more efficient "gossipsub" implementation
  * Files can now be ignored on add by passing the --ignore and/or
  - -ignore-rules-path flags.
  * It's now possible to add data directly from a named pipe
  * Systemd Support
  * socket activation and startup/shutdown notifications
  * IPFS API Over Unix Domain Sockets
  * After install run ipfs daemon --migrate
* Fri Jan 31 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.4.23
  * Fixed Panics and Crashes
  * Fixed Spontaneous TLS Disconnects
  * Better Bitswap
  * Reduced Relay Related DHT Spam
  * Retuned Connection Manager
  * Fixed Resursive Resolving of dnsaddr Multiaddrs
* Wed Aug  7 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.4.22
  progress on #6506
  Key bug fixes:
    Too many open file descriptors/too many peers (#6237).
    Adding multiple files at the same time doesn't work (#6254).
    CPU utilization spikes and then holds at 100%% (#5613).
  Key features:
    Experimental TLS1.3 support (to eventually replace secio).
    OpenSSL support for SECIO handshakes (performance improvement).
* Tue Apr 30 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.4.20
  * fixed a frequent panic in the DHT
  * workaround stuck transfers
  * See https://github.com/ipfs/go-ipfs/releases/tag/v0.4.20
    for full changes
* Mon Mar 11 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Require fuse at runtime
- Include docs
* Tue Mar  5 2019 Pierre-Alain TORET <pierre-alain.toret@protonmail.com>
- Update to 0.4.19
* Fri Dec 14 2018 Pierre-Alain TORET <pierre-alain.toret@protonmail.com>
- Update to 0.4.18
